@@ -1,28 +1,30 @@
 /* misc.c - misc routines for jpeginfo
- * $Id: misc.c,v 1.3 1998/01/15 10:33:12 tjko Exp $
+ * $Id: misc.c,v 1.5 2002/12/10 09:58:34 tjko Exp $
  *
  * Copyright (c) Timo Kokkonen, 1997.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <sys/stat.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
+#include "jpeginfo.h"
 
-static char *rcsid = "$Id: misc.c,v 1.3 1998/01/15 10:33:12 tjko Exp $";
+static char *rcsid = "$Id: misc.c,v 1.5 2002/12/10 09:58:34 tjko Exp $";
 
 
 int is_dir(FILE *fp)
 {
  struct stat buf;
-
- if (fstat(fileno(fp),&buf)) {
-   fprintf(stderr,"jpeginfo: fstat() failed.\n");
-   exit(3);
- }
  
+ if (!fp) return 0;
+ if (fstat(fileno(fp),&buf)) return 0;
  if (S_ISDIR(buf.st_mode)) return 1;
-
  return 0;
 }
 
@@ -31,21 +33,19 @@ long filesize(FILE *fp)
 {
   struct stat buf;
 
-  if (fstat(fileno(fp),&buf)) {
-    fprintf(stderr,"jpeginfo: fstat() failed.\n");
-    exit(3);
-  }
-
+  if (!fp) return -1;
+  if (fstat(fileno(fp),&buf)) return -1;
   return buf.st_size;
 }
 
 
 void delete_file(char *name, int verbose_mode, int quiet_mode)
 {
-  if (rcsid); 
+  if (rcsid); /* so the compiler cannot optimize our rcsid string :) */
 
-  if (verbose_mode&&!quiet_mode) fprintf(stderr,"deleting: %s\n",name);
-  if (unlink(name)&&!quiet_mode) 
+  if (!name) return;
+  if (verbose_mode && !quiet_mode) fprintf(stderr,"deleting: %s\n",name);
+  if (unlink(name) && !quiet_mode) 
     fprintf(stderr,"Error unlinking file: %s\n",name);
 }
 
@@ -54,6 +54,7 @@ char *fgetstr(char *s,int n,FILE *stream)
 {
   char *p;
   
+  if (!stream || !s || n < 1) return NULL;
   if (!fgets(s,n,stream)) return NULL;
   p=&s[strlen(s)-1];
   while ((p>=s)&&((*p==10)||(*p==13))) *p--=0;
@@ -84,6 +85,7 @@ char *md2str(unsigned char *digest, char *s)
   return r;
 }
 
+/* eof :-) */
 
 
 
